@@ -15,7 +15,7 @@ override _build_WriteMakefile_dump => sub {
    my $txt = super();
 
    $txt =~ s/([\'\"]?PREREQ_PM[\'\"]? => \{)/$1\n    &os_deps,/g;
-   
+
    return $txt;
 };
 
@@ -25,41 +25,30 @@ override _build_MakeFile_PL_template => sub {
 
    $template .= <<'TEMPLATE';
 sub os_deps {
-   my $_os = lc($^O);
-
-   if ( $_os =~ /mswin32|cygwin/ ) {
+   if ( $^O eq 'MSWin32' or $^O eq 'cygwin' ) {
       return (
          'Win32::Process'       => 0,
          'Win32::Process::Info' => 1.020,  # WMI on Cygwin
          'Path::Class'          => 0.32,   # fixes Cygwin path issue
       );
    }
-   elsif ( $_os eq 'freebsd' ) {
+   elsif ( $^O eq 'freebsd' ) {
       return ( 'BSD::Process' => 0 );
    }
-   elsif ( $_os eq 'darwin' ) {
-      return ( 'Proc::ProcessTable' => 0.45 );
-   }
-   elsif ( $_os eq 'os2' ) {
+   elsif ( $^O eq 'os2' ) {
       return ( 'OS2::Process' => 0 );
    }
-   elsif ( $_os eq 'vms' ) {
+   elsif ( $^O eq 'VMS' ) {
       return ( 'VMS::Process' => 0 );
    }
-   elsif ( $_os eq 'dos' ) {
-      die "Heh, DOS processes... you're funny!";
-   }
    else {
       # let's hope they have /proc
-      if ( not -d '/proc' ) {
-         if ( $_os =~ /bsd|dragonfly/ ) {
-            die "BSD::Process only works for FreeBSD."
-              . " Encourage development for $_os, or write your own and I can include it here.";
-         }
-         else {
-            die "No idea how to handle $_os processes."
-              . " Email me with more information!";
-         }
+      if ( -d '/proc' and @{[ glob('/proc/*') ]} ) {
+         return ();
+      }
+      # ...or that Proc::ProcessTable can handle it
+      else {
+         return ( 'Proc::ProcessTable' => 0.48 );  # ie: the one that ain't broke
       }
    }
    return ();
